;; Generated package description from denote-review.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "denote-review" "1.0.3" "implements review process for denote notes" '((emacs "28.1") (denote "4.1.3")) :commit "06732385c0022bfbcb6efe28440025479de2486b" :authors '(("Matto Fransen" . "matto@matto.nl")) :maintainer '("Matto Fransen" . "matto@matto.nl") :keywords '("files") :url "https://codeberg.org/mattof/denote-review")
